Coverage for ejpiaj/decorators: 100%

# Coverage for ejpiaj/decorators : 100%

## 11 statements 11 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | from .registry import register_variables_extractor, register_assertion def variable_extractor(key): def decorator(function): register_variables_extractor(key, function) return function return decorator def assertion(key): def decorator(function): register_assertion(key, function) return function return decorator